@@ -47,10 +47,11 @@ int main(int argc, char** argv)
     parser.addOption(QCommandLineOption(QStringLiteral("unpair"), i18n("Stop pairing to a said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("ping"), i18n("Sends a ping to said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("ping-msg"), i18n("Same as ping but you can set the message to display"), i18n("message")));
-    parser.addOption(QCommandLineOption(QStringLiteral("share"), i18n("Share a file to a said device"), QStringLiteral("path")));
+    parser.addOption(QCommandLineOption(QStringLiteral("share"), i18n("Share a file/URL to a said device"), QStringLiteral("path or URL")));
     parser.addOption(QCommandLineOption(QStringLiteral("share-text"), i18n("Share text to a said device"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringLiteral("list-notifications"), i18n("Display the notifications on a said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("lock"), i18n("Lock the specified device")));
+    parser.addOption(QCommandLineOption(QStringLiteral("unlock"), i18n("Unlock the specified device")));
     parser.addOption(QCommandLineOption(QStringLiteral("send-sms"), i18n("Sends an SMS. Requires destination"), i18n("message")));
     parser.addOption(QCommandLineOption(QStringLiteral("destination"), i18n("Phone number to send the message"), i18n("phone number")));
     parser.addOption(QCommandLineOption(QStringLiteral("attachment"), i18n("File urls to send attachments with the message (can be passed multiple times)"), i18n("file urls")));
@@ -80,14 +81,14 @@ int main(int argc, char** argv)
     if (parser.isSet(QStringLiteral("my-id"))) {
         QTextStream(stdout) << iface.selfId() << endl;
     } else if (parser.isSet(QStringLiteral("l")) || parser.isSet(QStringLiteral("a"))) {
-        bool reachable = false;
+        bool available = false;
         if (parser.isSet(QStringLiteral("a"))) {
-            reachable = true;
+            available = true;
         } else {
             blockOnReply(iface.acquireDiscoveryMode(id));
             QThread::sleep(2);
         }
-        const QStringList devices = blockOnReply<QStringList>(iface.devices(reachable, false));
+        const QStringList devices = blockOnReply<QStringList>(iface.devices(available, available));
 
         bool displayCount = true;
         for (const QString& id : devices) {
@@ -157,7 +158,7 @@ int main(int argc, char** argv)
         return int(devices.isEmpty());
     } else if(parser.isSet(QStringLiteral("refresh"))) {
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect"), QStringLiteral("org.kde.kdeconnect.daemon"), QStringLiteral("forceOnNetworkChange"));
-        blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+        blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
     } else {
 
         QString device = parser.value(QStringLiteral("device"));
@@ -195,7 +196,7 @@ int main(int argc, char** argv)
                                                               QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrls"));
 
             msg.setArguments(QVariantList() << QVariant(urls));
-            blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
 
             for (const QString& url : qAsConst(urls)) {
                 QTextStream(stdout) << i18n("Shared %1", url) << endl;
@@ -203,8 +204,18 @@ int main(int argc, char** argv)
         } else if (parser.isSet(QStringLiteral("share-text"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/share"), QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareText"));
             msg.setArguments(QVariantList() << parser.value(QStringLiteral("share-text")));
-            blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             QTextStream(stdout) << i18n("Shared text: %1", parser.value(QStringLiteral("share-text"))) << endl;
+        } else if (parser.isSet(QStringLiteral("lock")) || parser.isSet(QStringLiteral("unlock"))) {
+            LockDeviceDbusInterface iface(device);
+            iface.setLocked(parser.isSet(QStringLiteral("lock")));
+
+            DeviceDbusInterface deviceIface(device);
+            if (parser.isSet(QStringLiteral("lock"))) {
+                QTextStream(stdout) << i18nc("device has requested to lock peer device", "Requested to lock %1.", deviceIface.name()) << endl;
+            } else {
+                QTextStream(stdout) << i18nc("device has requested to unlock peer device", "Requested to unlock %1.", deviceIface.name()) << endl;
+            }
         } else if(parser.isSet(QStringLiteral("pair"))) {
             DeviceDbusInterface dev(device);
             if (!dev.isReachable()) {
@@ -246,7 +257,7 @@ int main(int argc, char** argv)
                 QString message = parser.value(QStringLiteral("ping-msg"));
                 msg.setArguments(QVariantList() << message);
             }
-            blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
         } else if(parser.isSet(QStringLiteral("send-sms"))) {
             if (parser.isSet(QStringLiteral("destination"))) {
                 qDBusRegisterMetaType<ConversationAddress>();
@@ -274,18 +285,18 @@ int main(int argc, char** argv)
 
                 reply.waitForFinished();
             } else {
-                QTextStream(stderr) << i18n("error: should specify the SMS's recipient by passing --destination <phone number>");
+                QTextStream(stderr) << i18n("error: should specify the SMS's recipient by passing --destination <phone number>") << endl;
                 return 1;
             }
         } else if(parser.isSet(QStringLiteral("ring"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/findmyphone"), QStringLiteral("org.kde.kdeconnect.device.findmyphone"), QStringLiteral("ring"));
-            blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
         } else if(parser.isSet(QStringLiteral("photo"))) {
             const QString fileName = parser.value(QStringLiteral("photo"));
             if (!fileName.isEmpty()) {
                 QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/photo"), QStringLiteral("org.kde.kdeconnect.device.photo"), QStringLiteral("requestPhoto"));
                 msg.setArguments({fileName});
-                blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             } else {
                 QTextStream(stderr) << i18n("Please specify a filename for the photo") << endl;
             }
@@ -299,13 +310,13 @@ int main(int argc, char** argv)
                     while (!in.atEnd()) {
                         QByteArray line = in.readLine();  // sanitize to ASCII-codes > 31?
                         msg.setArguments({QString::fromLatin1(line), -1, false, false, false});
-                        blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+                        blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
                     }
                     in.close();
                 }
             } else {
                 msg.setArguments({seq, -1, false, false, false});
-                blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             }
         } else if(parser.isSet(QStringLiteral("list-notifications"))) {
             NotificationsModel notifications;
