@@ -1,21 +1,7 @@
 /**
- * Copyright 2015 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2015 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "kdeconnectconfig.h"
@@ -53,11 +39,29 @@ struct KdeConnectConfigPrivate {
     QSettings* m_config;
     QSettings* m_trustedDevices;
 
-#ifdef USE_PRIVATE_DBUS
+#ifdef Q_OS_MAC
     QString m_privateDBusAddress;  // Private DBus Address cache
 #endif
 };
 
+static QString getDefaultDeviceName() {
+#ifdef SAILFISHOS
+    const QString hwReleaseFile = QStringLiteral("/etc/hw-release");
+    // QSettings will crash if the file does not exist or can be created, like in this case by us in /etc.
+    // E.g. in the SFOS SDK Emulator there is no such file, so check before to protect against the crash.
+    if (QFile::exists(hwReleaseFile)) {
+        QSettings hwRelease(hwReleaseFile, QSettings::IniFormat);
+        auto hwName = hwRelease.value(QStringLiteral("NAME")).toString();
+        if (!hwName.isEmpty()) {
+            return hwName;
+        }
+    }
+#endif
+
+    return QHostInfo::localHostName();
+}
+
+
 KdeConnectConfig& KdeConnectConfig::instance()
 {
     static KdeConnectConfig kcc;
@@ -86,19 +90,15 @@ KdeConnectConfig::KdeConnectConfig()
 
     loadPrivateKey();
     loadCertificate();
+
+    if (name().isEmpty()) {
+        setName(getDefaultDeviceName());
+    }
 }
 
 QString KdeConnectConfig::name()
 {
-    QString username;
-    #ifdef Q_OS_WIN
-        username = QString::fromLatin1(qgetenv("USERNAME"));
-    #else
-        username = QString::fromLatin1(qgetenv("USER"));
-    #endif
-    QString defaultName = username + QStringLiteral("@") + QHostInfo::localHostName();
-    QString name = d->m_config->value(QStringLiteral("name"), defaultName).toString();
-    return name;
+    return d->m_config->value(QStringLiteral("name")).toString();
 }
 
 void KdeConnectConfig::setName(const QString& name)
@@ -195,6 +195,10 @@ void KdeConnectConfig::removeTrustedDevice(const QString& deviceId)
 // Utility functions to set and get a value
 void KdeConnectConfig::setDeviceProperty(const QString& deviceId, const QString& key, const QString& value)
 {
+    // do not store values for untrusted devices (it would make them trusted)
+    if (!trustedDevices().contains(deviceId))
+        return;
+
     d->m_trustedDevices->beginGroup(deviceId);
     d->m_trustedDevices->setValue(key, value);
     d->m_trustedDevices->endGroup();
@@ -210,6 +214,16 @@ QString KdeConnectConfig::getDeviceProperty(const QString& deviceId, const QStri
     return value;
 }
 
+void KdeConnectConfig::setCustomDevices(const QStringList& addresses)
+{
+    d->m_config->setValue(QStringLiteral("customDevices"), addresses);
+    d->m_config->sync();
+}
+
+QStringList KdeConnectConfig::customDevices() const
+{
+    return d->m_config->value(QStringLiteral("customDevices")).toStringList();
+}
 
 QDir KdeConnectConfig::deviceConfigDir(const QString& deviceId)
 {
@@ -348,7 +362,7 @@ void KdeConnectConfig::generateCertificate(const QString& certPath)
     }
 }
 
-#ifdef USE_PRIVATE_DBUS
+#ifdef Q_OS_MAC
 QString KdeConnectConfig::privateDBusAddressPath()
 {
     return baseConfigDir().absoluteFilePath(QStringLiteral("private_dbus_address"));
