@@ -27,6 +27,7 @@
 #include "shareinterface.h"
 #include "remotesystemvolumeinterface.h"
 #include "bigscreeninterface.h"
+#include "virtualmonitorinterface.h"
 
 /**
  * Using these "proxy" classes just in case we need to rename the
@@ -247,7 +248,7 @@ class KDECONNECTINTERFACES_EXPORT RemoteSystemVolumeDbusInterface
     Q_OBJECT
 public:
     explicit RemoteSystemVolumeDbusInterface(const QString& deviceId, QObject* parent = nullptr);
-    ~RemoteSystemVolumeDbusInterface() = default;
+    ~RemoteSystemVolumeDbusInterface() override = default;
 };
 
 class KDECONNECTINTERFACES_EXPORT BigscreenDbusInterface
@@ -259,6 +260,15 @@ public:
     ~BigscreenDbusInterface() override;
 };
 
+class KDECONNECTINTERFACES_EXPORT VirtualmonitorDbusInterface
+    : public OrgKdeKdeconnectDeviceVirtualmonitorInterface
+{
+    Q_OBJECT
+public:
+    explicit VirtualmonitorDbusInterface(const QString& deviceId, QObject* parent = nullptr);
+    ~VirtualmonitorDbusInterface() override;
+};
+
 template <typename T, typename W>
 static void setWhenAvailable(const QDBusPendingReply<T>& pending, W func, QObject* parent)
 {
